<?php

/*
 * This plugin is currently available for use in all personal
 * or commercial projects under both MIT and GPL licenses. This
 * means that you can choose the license that best suits your
 * project, and use it accordingly.
 *
 * MIT License: http://www.tierra-innovation.com/license/MIT-LICENSE.txt
 * GPL2 License: http://www.tierra-innovation.com/license/GPL-LICENSE.txt
 */


#################
#     SETUP     #
#################

/* Return an array of option names */
function get_ti_fbl_options_array()
{
		return array(
			'_ti_fbl_site_name',

			'_ti_fbl_title',
			'_ti_fbl_type',
			'_ti_fbl_url',
			'_ti_fbl_image',
			'_ti_fbl_description',

			'_ti_fbl_latitude',
			'_ti_fbl_longitude',
			'_ti_fbl_street_address',
			'_ti_fbl_locality',
			'_ti_fbl_region',
			'_ti_fbl_postal_code',
			'_ti_fbl_country_name',

			'_ti_fbl_email',
			'_ti_fbl_phone_number',
			'_ti_fbl_fax_number',

			'_ti_fbl_admins',
			'_ti_fbl_app_id',

			'_ti_fbl_layout_style',
			'_ti_fbl_layout_faces',
			'_ti_fbl_layout_width',
			'_ti_fbl_layout_height',
			'_ti_fbl_layout_verb',
			'_ti_fbl_layout_font',
			'_ti_fbl_layout_scheme'
			
		);
}


/* Get options */
function get_ti_fbl_options() {

	global $ti_fbl_options;

	$options = get_ti_fbl_options_array();

	foreach ($options as $option)
	{
		$ti_fbl_options->self[$option] = htmlspecialchars(stripslashes(get_option($option)));
		
		if (is_numeric($_GET['post']) > 0 && $ti_fbl_options->self[$option] !== '')
		{
			$ti_fbl_cur_option = htmlspecialchars(stripslashes($ti_fbl_options->self[$option]));
			
			if ($ti_fbl_cur_option == 'true')
				$ti_fbl_cur_option = 'Yes';
			
			if ($ti_fbl_cur_option == 'button_count')
				$ti_fbl_cur_option = 'Button Count';
			
			// Attempt to present the default options in proper title case
			if (strstr($option, '_ti_fbl_layout') || $option == '_ti_fbl_type')
				$ti_fbl_cur_option = ucwords($ti_fbl_cur_option);
			
			$ti_fbl_options->default[$option] = '<strong>Default:</strong> '.$ti_fbl_cur_option;
		}
	}
}


/* Set option overrides */
function get_ti_fbl_options_for_post($override_all=false)
{
	global $post,$ti_fbl_options;

	if ($post->ID > 0)
	{
		$options = get_ti_fbl_options_array();

		foreach ($options as $option)
		{
			$override = get_post_meta($post->ID, $option, true);

			if ($override_all == false)
			{
				if ($override !== '')
					$ti_fbl_options->self[$option] = htmlspecialchars(stripslashes($override));
			}
			else
			{
				$ti_fbl_options->self[$option] = htmlspecialchars(stripslashes($override));
			}
		}
	}
}


###################
#    FRONT END    #
###################

/*****************/
/* ADD META TAGS */
/*****************/

/* Generates Meta Tags for front end site header */
function ti_fbl_meta() {

	global $wpdb,$post,$ti_fbl_options;

	$html = '';

	if ($post->ID > 0)
	{

		/* Get post specific overrides */
		get_ti_fbl_options_for_post();

		/* Site Name */
		if ($ti_fbl_options->self['_ti_fbl_site_name'] !== '')
		$html .= '	<meta property="og:site_name" content="'.$ti_fbl_options->self['_ti_fbl_site_name'].'"/>'."\n";

		/* Title - Use default page title if no override set */
		if ($ti_fbl_options->self['_ti_fbl_title'] == '')
			$ti_fbl_options->self['_ti_fbl_title'] = $post->post_title;

		$html .= '	<meta property="og:title" content="'.$ti_fbl_options->self['_ti_fbl_title'].'" />'."\n";

		/* Type */
		$post_type = get_post_meta($post->ID, '_ti_fbl_type', true);
		if ($ti_fbl_options->self['_ti_fbl_type'] !== '')
			$html .= '	<meta property="og:type" content="'.$ti_fbl_options->self['_ti_fbl_type'].'" />'."\n";

		/* URL */
		$html .= '	<meta property="og:url" content="'.$post->guid.'" />'."\n";

			/* Use first image attached to post */
			function ti_fbl_single_post_img_url($ti_fbl_img_size) {

				global $post;

				$attachments = get_children( array('post_parent' => $post->ID, 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => 'ASC', 'numberposts' => 1) );

				if ($attachments == true) :

					foreach($attachments as $id => $attachment) :
						$ti_fbl_img = wp_get_attachment_image_src($id, $ti_fbl_img_size);			
					endforeach;		

				endif;

				return $ti_fbl_img[0];

			}

		$ti_fbl_img_url = ti_fbl_single_post_img_url('thumbnail');

		if ($ti_fbl_img_url != '')
			$html .= '	<meta property="og:image" content="'.$ti_fbl_img_url.'" />'."\n";


		/* Description */
		if ($ti_fbl_options->self['_ti_fbl_description'] !== '')
		$html .= '	<meta property="og:description" content="'.$ti_fbl_options->self['_ti_fbl_description'].'"/>'."\n";

		/* Location */
		if ($ti_fbl_options->self['_ti_fbl_latitude'] !== '')
		$html .= '	<meta property="og:latitude" content="'.$ti_fbl_options->self['_ti_fbl_latitude'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_longitude'] !== '')
		$html .= '	<meta property="og:longitude" content="'.$ti_fbl_options->self['_ti_fbl_longitude'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_street_address'] !== '')
		$html .= '	<meta property="og:street-address" content="'.$ti_fbl_options->self['_ti_fbl_street_address'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_locality'] !== '')
		$html .= '	<meta property="og:locality" content="'.$ti_fbl_options->self['_ti_fbl_locality'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_region'] !== '')
		$html .= '	<meta property="og:region" content="'.$ti_fbl_options->self['_ti_fbl_region'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_postal_code'] !== '')
		$html .= '	<meta property="og:postal-code" content="'.$ti_fbl_options->self['_ti_fbl_postal_code'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_country_name'] !== '')
		$html .= '	<meta property="og:country-name" content="'.$ti_fbl_options->self['_ti_fbl_country_name'].'"/>'."\n";

		/* Contact Information */
		if ($ti_fbl_options->self['_ti_fbl_email'] !== '')
		$html .= '	<meta property="og:email" content="'.$ti_fbl_options->self['_ti_fbl_email'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_phone_number'] !== '')
		$html .= '	<meta property="og:phone_number" content="'.$ti_fbl_options->self['_ti_fbl_phone_number'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_fax_number'] !== '')
		$html .= '	<meta property="og:fax_number" content="'.$ti_fbl_options->self['_ti_fbl_fax_number'].'"/>'."\n";

		/* FB App ID and Admins */
		if ($ti_fbl_options->self['_ti_fbl_app_id'] !== '')
		$html .= '	<meta property="fb:app_id" content="'.$ti_fbl_options->self['_ti_fbl_app_id'].'"/>'."\n";

		if ($ti_fbl_options->self['_ti_fbl_admins'] !== '')
		$html .= '	<meta property="fb:admins" content="'.$ti_fbl_options->self['_ti_fbl_admins'].'"/>'."\n";


	}

	echo $html;
}


/***********************/
/* DISPLAY LIKE BUTTON */
/***********************/

function ti_fbl_render_button() {

	global $post,$ti_fbl_options;

	$ti_fbl_options->self['ti_fbl_button_config'] = '';

	/* Page URL */
	$ti_fbl_options->self['ti_fbl_button_config'] .= '?href='.urlencode(post_permalink());

	if ($ti_fbl_options->self['_ti_fbl_layout_style'] !== '')
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;layout='.$ti_fbl_options->self['_ti_fbl_layout_style'];


	/* Show Faces */
	if ($ti_fbl_options->self['_ti_fbl_layout_faces'] == "true")
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;show_faces=true';
	else
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;show_faces=false';

	/* Width */
	if ($ti_fbl_options->self['_ti_fbl_layout_width'] !== '')
	{
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;width='.$ti_fbl_options->self['_ti_fbl_layout_width'];
		$ti_fbl_options->self['ti_fbl_button_config_style'] .= ' width:'.$ti_fbl_options->self['_ti_fbl_layout_width'].'px;';
	}
	else
	{
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;width=450';
		$ti_fbl_options->self['ti_fbl_button_config_style'] .= ' width:450px;';
	}

	/* Height */
	if ($ti_fbl_options->self['_ti_fbl_layout_height'] !== '')
		$ti_fbl_options->self['ti_fbl_button_config_style'] .= ' height:'.$ti_fbl_options->self['_ti_fbl_layout_height'].'px';
	else
		$ti_fbl_options->self['ti_fbl_button_config_style'] .= ' height:px';

	/* Action (like/recommend) */
	if ($ti_fbl_options->self['_ti_fbl_layout_verb'] == '')
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;action=like';
	else
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;action='.$ti_fbl_options->self['_ti_fbl_layout_verb'];

	/* Font */
	if ($ti_fbl_options->self['_ti_fbl_layout_font'] !== '')
		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;font='.$ti_fbl_options->self['_ti_fbl_layout_font'];

	/* Scheme (light/dark) */
	if ($ti_fbl_options->self['_ti_fbl_layout_scheme'] !== '')
 		$ti_fbl_options->self['ti_fbl_button_config'] .= '&amp;colorscheme='.$ti_fbl_options->self['_ti_fbl_layout_scheme'];

	return '<iframe src="http://www.facebook.com/plugins/like.php'.$ti_fbl_options->self['ti_fbl_button_config'].'" scrolling="no" frameborder="0" allowTransparency="true" style="border:none; overflow:hidden; '.$ti_fbl_options->self['ti_fbl_button_config_style'].'"></iframe>';

}

// Function for templates
function facebook_ilike($echo=true)
{
	if ($echo == true)
		echo ti_fbl_render_button();
	else
		return ti_fbl_render_button();
}

function ti_fbl_remove_shortcode_from_rss($content) {
	return preg_replace("/\[TI_([^\]]*)\]/i", "", $content);
}


##################
#    BACK END    #
##################

/**************/
/* MENU ITEMS */
/**************/

/* Add admin menu item */
function modify_ti_fbl_menu() {
	add_options_page(
		'Facebook iLike', // page title
		'Facebook iLike', // sub-menu title
		'manage_options', // access/capa
		'facebook-ilike.php', // file
		'admin_ti_fbl_options' // function
	);
}


/*************/
/* EDIT FORM */
/*************/

/* Adds a custom section to the "advanced" Post and Page edit screens */
function ti_fbl_add_custom_box() {
	if ( function_exists( 'add_meta_box' )) {
		add_meta_box( 'ti_fbl_sectionid', __( 'Facebook iLike', 'ti_fbl_textdomain' ), 'ti_fbl_inner_custom_box', 'post', 'advanced' );
		add_meta_box( 'ti_fbl_sectionid', __( 'Facebook iLike', 'ti_fbl_textdomain' ), 'ti_fbl_inner_custom_box', 'page', 'advanced' );
	} else {
		add_action('dbx_post_advanced', 'ti_fbl_old_custom_box' );
		add_action('dbx_page_advanced', 'ti_fbl_old_custom_box' );
	}
}

/*********************/
/* EDIT/SAVE ACTIONS */
/*********************/

/* Update settings from post */
function admin_ti_fbl_options() {
	
	global $post;

	if ($_POST['submit'])
	{
		// Update the options
		update_ti_fbl_options();
		
		// Reset the default option values in the class
		get_ti_fbl_options();
		
		// Reset post specific overrides
		if ($post->ID > 0)
			get_ti_fbl_options_for_post();
	}

	// Print out the options form
	print_ti_fbl_form();
}

/* Update settings */
function update_ti_fbl_options() {

		$options = get_ti_fbl_options_array();

		foreach ($options as $option)
		{
			if (isset($_POST[$option]))
				update_option($option,$_POST[$option]);
			else
				delete_option($option);
		}

    echo "
        <div id='message' class='updated fade'>
            <p>Options saved.</p>
        </div>
    ";
}

/* When the post is saved, saves our custom data */
function ti_fbl_save_postdata( $post_id ) {

	// Verify this post came from the our edit screen and with proper authorization,
	// because save_post can be triggered at other times.
	if ( !wp_verify_nonce( $_POST['_ti_fbl_noncename'], plugin_basename(__FILE__) )) {
		return $post_id;
	}

	// Check if this is an auto save routine. If it is, our form has not been submitted,
	// so we don't want to do anything yet.
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
		return $post_id;

	// Check update permissions
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) )
			return $post_id;
	} else {
		if ( !current_user_can( 'edit_post', $post_id ) )
			return $post_id;
	}

	// We're authenticated. Now find and save the data.
	foreach ($_POST as $key => $val)
	{
		if (strstr($key, 'ti_fbl'))
		{
			add_post_meta($post_id, $key, $val, true) or update_post_meta($post_id, $key, $val);
		}
	}

	return true;
}


/***************/
/* HTML OUTPUT */
/***************/

/* Print form in admin */
function print_ti_fbl_form() {

	global $ti_fbl_options;

	print '
		<div class="wrap">

			<div id="icon-options-general" class="icon32"><img src="http://tierra-innovation.com/wordpress-cms/logos/src/facebook-ilike/1.0/default.gif" alt="" title="" /><br /></div>

			<h2>Facebook iLike Default Options</h2>
			
			<p><strong>On this page you can specify the default options to be used across all pages of the site. Each option can be modified per post or page on the post/page edit screen.</strong></p>

			'.ti_fbl_form_embed().'

			<form method="post" id="fb_ilike_form">

				<h4 style="font-size: 13px;">Plugin Settings</h4>
				<table cellspacing="0" cellpadding="0">
				<tr>
					<td class="label first"><label for="_ti_fbl_site_name">' . __("Site Name", "_ti_fbl_site_name" ) . '</label></td>
					<td class="field first"><input type="text" name="_ti_fbl_site_name" value="' . $ti_fbl_options->self["_ti_fbl_site_name"] . '" size="25" /></td>
				</tr>
				<tr>
					<td class="label"><label for="_ti_fbl_admins">' . __("Facebook Admins", "_ti_fbl_admins" ) . '</label></td>
					<td class="field">
					
					<p style="margin: 2px 0 0 0;">Once users have liked your page, you can publish stream updates to those users and get statistics about your pages, just like you can with Facebook Pages. To administer your page you need to associate it with your Facebook account. To do so, add a comma-separated list of the user IDs or usernames of the Facebook accounts who own the pages here:</p>
					
					<p><input type="text" name="_ti_fbl_admins" value="' . $ti_fbl_options->self["_ti_fbl_admins"] . '" size="25" /></p>
					
					<p>Each listed user must click Like on the URL to be approved as an admin. This is to prevent users being made admins without their consent. Also, the first user listed in this tag cannot be removed, or moved later in the list of user IDs.</p>

					<p>Once you have associated the page with your Facebook account, the page will show up in Pages You Admin on Facebook. From that interface, you can publish stream updates and get detailed analytics about the users who have liked your page.</p>
					
					</td>
				</tr>
				<tr>
					<td class="label"><label for="_ti_fbl_app_id">' . __("Facebook App ID", "_ti_fbl_app_id" ) . '</label></td>
					<td class="field">
					
					<p style="margin: 2px 0 0 0;">Some sites may have hundreds or even thousands of pages with meta data. To handle a site with lots of pages, you can link your pages to your Facebook Platform application, which will enable you to publish stream updates to your pages programmatically. To connect your Page to your Facebook application ID, include your application\'s ID here:</p>
					<p><input type="text" name="_ti_fbl_app_id" value="' . $ti_fbl_options->self["_ti_fbl_app_id"] . '" size="25" /></p>

					</td>
				</tr>
				</table>

				'.ti_fbl_inner_custom_box(false).'

				<br />
				<input type="submit" name="submit" class="button-primary" value="Save Options" /><br /><br />

			</form>
		</div>
		
	';

}

function ti_fbl_form_embed() {

	return '
			<div class="embed">
				<h4>How To Embed The Code</h4>

				<p>To embed the "Like" button in a post or a page, paste this code into your post/page at the desired location:<br /><br /><code>[facebook_ilike]</code></p>
			
				<p>If you prefer to embed the "Like" button in your theme\'s templates rather than within specific posts, use this PHP code in your template:<br /><br /><code>&lt;?php facebook_ilike(); ?&gt;</code></p>

			</div>

			<style type="text/css">
				div.embed { background:#fefff0; padding: 10px; }
				div.embed h4{ font-size: 1.3em; margin: 0; padding: 5px; }
				div.embed p { font-size: 12px !important; }
				div.embed code { font-size: 1.25em; background: #ddfee1; display:inline-block; margin: 0 0 10px 0; padding: 10px; }

				form#fbilike_form h4,
				div#ti_fbl_sectionid h4 { font-size: 14px !important }

				form#fb_ilike_form td,
				div#ti_fbl_sectionid td { padding: 7px 5px 5px 5px; border-bottom: 1px solid #c2c2c2 !important; }

				div#ti_fbl_sectionid td.label { padding: 10px 5px 5px 5px; }

				form#fb_ilike_form td.first,
				div#ti_fbl_sectionid td.first { border-top: 1px solid #c2c2c2; }

				form#fb_ilike_form td.label,
				div#ti_fbl_sectionid td.label { width: 125px; vertical-align:top; background: #fefff0; font-weight: bold; border-right: 1px solid #c2c2c2; }

			</style>
	';

}

/* Prints the inner fields for the custom post/page section */
function ti_fbl_inner_custom_box($echo=true) {

	global $post,$ti_fbl_options;

	if ($post->ID > 0)
	{
		get_ti_fbl_options_for_post(true);
		print ti_fbl_form_embed();
	}

	$html = '';

	// Use nonce for verification
	$html .= '<input type="hidden" name="_ti_fbl_noncename" id="_ti_fbl_noncename" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';

	// The actual fields for data entry
	$html .= '
		<h4>Layout</h4>
		<table cellspacing="0" cellpadding="0">
			<tr>
				<td class="label first"><label for="_ti_fbl_layout_style">' . __("Layout Style", '_ti_fbl_layout_style' ) . '</label></td>
				<td class="field first">
					<select name="_ti_fbl_layout_style">
						<option value=""> - Select One - </option>
						<option value="standard"'.($ti_fbl_options->self['_ti_fbl_layout_style'] == 'standard' ? ' selected=\"selected\"' : '').'>Standard</option>
						<option value="button_count"'.($ti_fbl_options->self['_ti_fbl_layout_style'] == 'button_count' ? ' selected=\"selected\"' : '').'>Button Count</option>
					</select>
				</td>
				<td class="first">'.$ti_fbl_options->default['_ti_fbl_layout_style'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_layout_faces">' . __("Show Faces", '_ti_fbl_layout_faces' ) . '</label></td>
				<td>
					<select name="_ti_fbl_layout_faces">
						<option value=""> - Select One - </option>
						<option value="true"'.($ti_fbl_options->self['_ti_fbl_layout_faces'] == 'true' ? ' selected=\"selected\"' : '').'>Yes</option>
						<option value="false"'.($ti_fbl_options->self['_ti_fbl_layout_faces'] == 'false' ? ' selected=\"selected\"' : '').'>No</option>
					</select>
				</td>
				<td>'.$ti_fbl_options->default['_ti_fbl_layout_faces'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_layout_width">' . __("Width", '_ti_fbl_layout_width' ) . '</label></td>
				<td>
						<input type="text" name="_ti_fbl_layout_width" id="_ti_fbl_layout_width" size="7" value="'.$ti_fbl_options->self['_ti_fbl_layout_width'].'" />px
				</td>
				<td>'.$ti_fbl_options->default['_ti_fbl_layout_width'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_layout_height">' . __("Height", '_ti_fbl_layout_height' ) . '</label></td>
				<td>
						<input type="text" name="_ti_fbl_layout_height" id="_ti_fbl_layout_height" size="7" value="'.$ti_fbl_options->self['_ti_fbl_layout_height'].'" />px
				</td>
				<td>'.$ti_fbl_options->default['_ti_fbl_layout_height'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_layout_verb">' . __("Verb to display", '_ti_fbl_layout_verb' ) . '</label></td>
				<td>
					<select name="_ti_fbl_layout_verb">
						<option value=""> - Select One - </option>
						<option value="like"'.($ti_fbl_options->self['_ti_fbl_layout_verb'] == 'like' ? ' selected=\"selected\"' : '').'>Like</option>
						<option value="recommend"'.($ti_fbl_options->self['_ti_fbl_layout_verb'] == 'recommend' ? ' selected=\"selected\"' : '').'>Recommend</option>
					</select>
				</td>
				<td>'.$ti_fbl_options->default['_ti_fbl_layout_verb'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_layout_font">' . __("Font", '_ti_fbl_layout_font' ) . '</label></td>
				<td>
					<select name="_ti_fbl_layout_font">
							<option value="">
								- Select One -
							</option>
							<option value="arial"'.($ti_fbl_options->self['_ti_fbl_layout_font'] == 'arial' ? ' selected=\"selected\"' : '').'>
								Arial
							</option>
							<option value="lucida grande"'.($ti_fbl_options->self['_ti_fbl_layout_font'] == 'lucida grande' ? ' selected=\"selected\"' : '').'>
								Lucida Grande
							</option>
							<option value="segoe ui"'.($ti_fbl_options->self['_ti_fbl_layout_font'] == 'segoe ui' ? ' selected=\"selected\"' : '').'>
								Segoe UI
							</option>
							<option value="tahoma"'.($ti_fbl_options->self['_ti_fbl_layout_font'] == 'tahoma' ? ' selected=\"selected\"' : '').'>
								Tahoma
							</option>
							<option value="trebuchet ms"'.($ti_fbl_options->self['_ti_fbl_layout_font'] == 'trebuchet ms' ? ' selected=\"selected\"' : '').'>
								Trebuchet MS
							</option>
							<option value="verdana"'.($ti_fbl_options->self['_ti_fbl_layout_font'] == 'verdana' ? ' selected=\"selected\"' : '').'>
								Verdana
							</option>
					</select>
				</td>
				<td>'.$ti_fbl_options->default['_ti_fbl_layout_font'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_layout_scheme">' . __("Color Scheme", '_ti_fbl_layout_scheme' ) . '</label></td>
				<td>
					<select name="_ti_fbl_layout_scheme">
							<option value=""> - Select One - </option>
							<option value="light"'.($ti_fbl_options->self['_ti_fbl_layout_scheme'] == 'light' ? ' selected=\"selected\"' : '').'>
								Light
							</option>
							<option value="dark"'.($ti_fbl_options->self['_ti_fbl_layout_scheme'] == 'dark' ? ' selected=\"selected\"' : '').'>
								Dark
							</option>
					</select>
				</td>
				<td>'.$ti_fbl_options->default['_ti_fbl_layout_scheme'].'</td>
			</tr>
		</table>
		
		
		<h4>Basic Information</h4>
		<table cellspacing="0" cellpadding="0">
			<tr>
				<td class="label first"><label for="_ti_fbl_title">' . __("Page Name", '_ti_fbl_title' ) . '</label></td>
				<td class="field first"><input type="text" name="_ti_fbl_title" value="'.$ti_fbl_options->self['_ti_fbl_title'].'" size="25" /></td>
				<td class="first">'.$ti_fbl_options->default['_ti_fbl_title'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_description">' . __("Page Description", '_ti_fbl_description' ) . '</label></td>
				<td><textarea name="_ti_fbl_description">'.$ti_fbl_options->self['_ti_fbl_description'].'</textarea></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_description'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_type">' . __("Page Type", '_ti_fbl_type' ) . '</label></td>
				<td>' . ti_fbl_type_dropdown($ti_fbl_options->self['_ti_fbl_type']) . '</td>
				<td>'.$ti_fbl_options->default['_ti_fbl_type'].'</td>
			</tr>
		</table>

		<h4>Location</h4>

		<table cellspacing="0" cellpadding="0">
			<tr>
				<td class="label first"><label for="_ti_fbl_latitude">' . __("Latitude", '_ti_fbl_latitude' ) . '</label></td>
				<td class="field first"><input type="text" name="_ti_fbl_latitude" value="'.$ti_fbl_options->self['_ti_fbl_latitude'].'" size="25" /></td>
				<td class="first">'.$ti_fbl_options->default['_ti_fbl_latitude'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_longitude">' . __("Longitude", '_ti_fbl_longitude' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_longitude" value="'.$ti_fbl_options->self['_ti_fbl_longitude'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_longitude'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_street_address">' . __("Street Address", '_ti_fbl_street_address' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_street_address" value="'.$ti_fbl_options->self['_ti_fbl_street_address'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_street_address'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_locality">' . __("City / Locality", '_ti_fbl_locality' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_locality" value="'.$ti_fbl_options->self['_ti_fbl_locality'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_locality'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_region">' . __("State / Region", '_ti_fbl_region' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_region" value="'.$ti_fbl_options->self['_ti_fbl_region'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_region'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_postal_code">' . __("Postal Code", '_ti_fbl_postal_code' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_postal_code" value="'.$ti_fbl_options->self['_ti_fbl_postal_code'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_postal_code'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_country_name">' . __("Country Name", '_ti_fbl_country_name' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_country_name" value="'.$ti_fbl_options->self['_ti_fbl_country_name'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_country_name'].'</td>
			</tr>
		</table>

		<h4>Contact Information</h4>

		<table cellspacing="0" cellpadding="0">
			<tr>
				<td class="label first"><label for="_ti_fbl_email">' . __("Email Address", '_ti_fbl_email' ) . '</label></td>
				<td class="field first"><input type="text" name="_ti_fbl_email" value="'.$ti_fbl_options->self['_ti_fbl_email'].'" size="25" /></td>
				<td class="first">'.$ti_fbl_options->default['_ti_fbl_email'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_phone_number">' . __("Phone Number", '_ti_fbl_phone_number' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_phone_number" value="'.$ti_fbl_options->self['_ti_fbl_phone_number'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_phone_number'].'</td>
			</tr>
			<tr>
				<td class="label"><label for="_ti_fbl_fax_number">' . __("Fax Number", '_ti_fbl_fax_number' ) . '</label></td>
				<td><input type="text" name="_ti_fbl_fax_number" value="'.$ti_fbl_options->self['_ti_fbl_fax_number'].'" size="25" /></td>
				<td>'.$ti_fbl_options->default['_ti_fbl_fax_number'].'</td>
			</tr>
		</table>

		';

	if ($echo == true)
		echo $html;
	else
		return $html;

}

/* Print the FB Like Type dropdown */
function ti_fbl_type_dropdown($type='') {

	return "
		<select name='_ti_fbl_type'>
			<option value=''> - Select One - </option>
			<optgroup label='Activities'>
				<option value='activity'".($type == 'activity' ? ' selected=\"selected\"' : '').">- Activity</option>
				<option value='sport'".($type == 'sport' ? ' selected=\"selected\"' : '').">- Sport</option>
			</optgroup>
			<optgroup label='Businesses'>
				<option value='bar'".($type == 'bar' ? ' selected=\"selected\"' : '').">- Bar</option>
				<option value='company'".($type == 'company' ? ' selected=\"selected\"' : '').">- Company</option>
				<option value='cafe'".($type == 'cafe' ? ' selected=\"selected\"' : '').">- Caf&eacute;</option>
				<option value='hotel'".($type == 'hotel' ? ' selected=\"selected\"' : '').">- Hotel</option>
				<option value='restaurant'".($type == 'restaurant' ? ' selected=\"selected\"' : '').">- Restaurant</option>
			</optgroup>
			<optgroup label='Groups'>
				<option value='cause'".($type == 'cause' ? ' selected=\"selected\"' : '').">- Cause</option>
				<option value='sports_league'".($type == 'sports_league' ? ' selected=\"selected\"' : '').">- Sports League</option>
				<option value='sports_team'".($type == 'sports_team' ? ' selected=\"selected\"' : '').">- Sports Team</option>
			</optgroup>
			<optgroup label='Organizations'>
				<option value='band'".($type == 'band' ? ' selected=\"selected\"' : '').">- Band</option>
				<option value='government'".($type == 'government' ? ' selected=\"selected\"' : '').">- Government</option>
				<option value='non_profit'".($type == 'non_profit' ? ' selected=\"selected\"' : '').">- Non-profit</option>
				<option value='school'".($type == 'school' ? ' selected=\"selected\"' : '').">- School</option>
				<option value='university'".($type == 'university' ? ' selected=\"selected\"' : '').">- University</option>
			</optgroup>
			<optgroup label='People'>
				<option value='actor'".($type == 'actor' ? ' selected=\"selected\"' : '').">- Actor</option>
				<option value='athlete'".($type == 'athlete' ? ' selected=\"selected\"' : '').">- Athlete</option>
				<option value='author'".($type == 'author' ? ' selected=\"selected\"' : '').">- Author</option>
				<option value='director'".($type == 'director' ? ' selected=\"selected\"' : '').">- Director</option>
				<option value='musician'".($type == 'musician' ? ' selected=\"selected\"' : '').">- Musician</option>
				<option value='politician'".($type == 'politician' ? ' selected=\"selected\"' : '').">- Politician</option>
				<option value='public_figure'".($type == 'public_figure' ? ' selected=\"selected\"' : '').">- Public Figure</option>
			</optgroup>
			<optgroup label='Places'>
				<option value='city'".($type == 'city' ? ' selected=\"selected\"' : '').">- City</option>
				<option value='country'".($type == 'country' ? ' selected=\"selected\"' : '').">- Country</option>
				<option value='landmark'".($type == 'landmark' ? ' selected=\"selected\"' : '').">- Landmark</option>
				<option value='state_province'".($type == 'state_province' ? ' selected=\"selected\"' : '').">- State / Province</option>
			</optgroup>
			<optgroup label='Products and Entertainment'>
				<option value='album'".($type == 'album' ? ' selected=\"selected\"' : '').">- Album</option>
				<option value='book'".($type == 'book' ? ' selected=\"selected\"' : '').">- Book</option>
				<option value='drink'".($type == 'drink' ? ' selected=\"selected\"' : '').">- Drink</option>
				<option value='food'".($type == 'food' ? ' selected=\"selected\"' : '').">- Food</option>
				<option value='game'".($type == 'game' ? ' selected=\"selected\"' : '').">- Game</option>
				<option value='product'".($type == 'product' ? ' selected=\"selected\"' : '').">- Product</option>
				<option value='song'".($type == 'song' ? ' selected=\"selected\"' : '').">- Song</option>
				<option value='movie'".($type == 'movie' ? ' selected=\"selected\"' : '').">- Movie</option>
				<option value='tv_show'".($type == 'tv_show' ? ' selected=\"selected\"' : '').">- TV Show</option>
			</optgroup>
			<optgroup label='Websites'>
				<option value='blog'".($type == 'blog' ? ' selected=\"selected\"' : '').">- Blog</option>
				<option value='website'".($type == 'website' ? ' selected=\"selected\"' : '').">- Website</option>
			</optgroup>
		</select>
	";

}
   
/* Prints the edit form for pre-WordPress 2.5 post/page */
function ti_fbl_old_custom_box() {

  echo '<div class="dbx-b-ox-wrapper">' . "\n";
  echo '<fieldset id="ti_fbl_fieldsetid" class="dbx-box">' . "\n";
  echo '<div class="dbx-h-andle-wrapper"><h3 class="dbx-handle">' . __( 'Facebook iLike', 'ti_fbl_textdomain' ) . "</h3></div>";   
   
  echo '<div class="dbx-c-ontent-wrapper"><div class="dbx-content">';

  // output editing form
  ti_fbl_inner_custom_box();

  // end wrapper
  echo "</div></div></fieldset></div>\n";
}


/****************************/
/* INSTALL/UNINSTALL PLUGIN */
/****************************/

// Set default option values when plugin is activated
function initialize_ti_fbl_options() {

	$options = get_ti_fbl_options_array();

	foreach ($options as $option)
	{
		add_option($option,'');
	}

	update_option('_ti_fbl_site_name', get_bloginfo('name'));
	update_option('_ti_fbl_description', get_bloginfo('description'));
	update_option('_ti_fbl_layout_style', 'standard');
	update_option('_ti_fbl_layout_faces', 'true');
	update_option('_ti_fbl_layout_verb', 'like');
	update_option('_ti_fbl_layout_width', '450');
	update_option('_ti_fbl_layout_height', '65');
	update_option('_ti_fbl_layout_scheme', 'light');
}

// Delete options upon deactivation
function unset_ti_fbl_options() {

	$options = get_ti_fbl_options_array();

	foreach ($options as $option)
	{
		delete_option($option);
	}

}

/********************/
/* HELPER FUNCTIONS */
/********************/

// Get current page URL
function thisPageURL() {
	$URL = 'http';

	if ($_SERVER["HTTPS"] == "on")
		$URL .= "s";

	$URL .= "://";

	if ($_SERVER["SERVER_PORT"] != "80")
		$URL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
	else
		$URL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];

	return $URL;
}

?>